diff --git a/bob/devtools/bootstrap.py b/bob/devtools/bootstrap.py
index 979766d49af85dcbbc23af6143cb6f4fcdf32ff8..c831b79f50a112f0cbe710d072ee78b01ddd3b74 100644
--- a/bob/devtools/bootstrap.py
+++ b/bob/devtools/bootstrap.py
@@ -504,9 +504,10 @@ if __name__ == "__main__":
     if args.verbose >= 3:
         conda_verbosity = ["-vv"]
 
     # clean all caches because we may have changed
     # the URL address of channels
     run_cmdline([conda_bin, "clean", "--all"] + conda_verbosity)
+    run_cmdline([conda_bin, "update", "--all"] + conda_verbosity)
 
     # print conda information for debugging purposes
     run_cmdline([conda_bin, "info"] + conda_verbosity)
@@ -504,9 +504,10 @@ if __name__ == "__main__":
         conda_verbosity = ["-vv"]
 
-    # clean all caches because we may have changed
+    # clean all caches and update, because we may have changed
     # the URL address of channels
     run_cmdline([conda_bin, "clean", "--all"] + conda_verbosity)